pub enum MachineStatusError {
InvalidConfiguration,
UnsupportedChange,
InsufficientResources,
CreateError,
UpdateError,
DeleteError,
JoinClusterTimeoutError,
}Variants
InvalidConfiguration
InvalidConfigurationMachineError represents that the combination of configuration in the MachineSpec is not supported by this cluster. This is not a transient error, but indicates a state that must be fixed before progress can be made.
Example: the ProviderSpec specifies an instance type that doesn’t exist,.
UnsupportedChange
InsufficientResources
CreateError
UpdateError
DeleteError
JoinClusterTimeoutError